module.exports = {
  encodeData,
  normalizeUrl
};

/**
 * Default ports of different protocols.
 *
 * @type {Object}
 */
const defaultPorts = {
  'http:': '80',
  'https:': '443'
};

/**
 * Encode a string according to RFC3986.
 *
 * @param  {String} str
 * @return {String}
 */
function encodeData(str) {
  if (str == null) {
    return '';
  }

  return encodeURIComponent(str)
    .replace(/'/g, '%27')
    .replace(/\(/g, '%28')
    .replace(/\)/g, '%29')
    .replace(/\*/g, '%2A')
    .replace(/!/g, '%21');
}

/**
 * Normalize the url for including with the hashed signature.
 *
 * @param  {Object} uri
 * @return {String}
 */
function normalizeUrl(uri) {
  let port = '';

  if (uri.port && defaultPorts[uri.protocol] !== uri.port) {
    port = `:${uri.port}`;
  }

  return `${uri.protocol}//${uri.hostname}${port}${uri.pathname}`;
}
