const url = require('url');
const request = require('request');
const { isObject } = require('../../utils');

module.exports = oAuth2Request;

function oAuth2Request(data, done) {
  // Check that we have an access token to use for the request and mix it in.
  if (isObject(data.oauth2) && data.oauth2.accessToken) {
    if ((data.oauth2.tokenType || '').toLowerCase() === 'bearer') {
      data.headers = Object.assign({
        Authorization: `Bearer ${data.oauth2.accessToken}`
      }, data.headers);
    } else {
      // Add the access token to the request query.
      const uri = url.parse(data.url, true);
      uri.query.access_token = data.oauth2.accessToken;
      delete uri.search;

      // Update ajax data headers and url.
      data.url = url.format(uri);
      data.headers = Object.assign({
        Pragma: 'no-store',
        'Cache-Control': 'no-store'
      }, data.headers);
    }
  }

  return request(data, done);
}
