const request = require('./ajax');

const isBrowser = !!process.browser;

module.exports = {
  expandAPI,
  resolveClient
};

function expandAPI(api) {
  api = api.expand ? api.expand(true) : api;

  const jsonOptions = {
    serializeMetadata: false,
    dumpSchemaContents: false,
    rootNodeDetails: false
  };

  return api.toJSON(jsonOptions);
}

function resolveClient({
  url, groupId, assetId, version, options
}) {
  if (isBrowser) {
    return new Promise((resolve, reject) => {
      if (typeof url === 'object') {
        resolve(url);
        return;
      }

      const headers = {
        Accept: 'application/json'
      };

      if (options.authorization) {
        headers.Authorization = options.authorization;
      }

      if (!url) {
        url = options.ramlQueryBuilder({ groupId, assetId, version });
      }

      request({ url, headers }, (err, xhr) => {
        if (err) {
          reject(err);
          return;
        }

        try {
          if (xhr.statusCode >= 300 && xhr.statusCode < 400) {
            throw new Error('Redirect is not supported.');
          } else if (xhr.statusCode >= 400) {
            throw new Error('Request has failed.');
          }

          resolve(JSON.parse(xhr.body));
        } catch (innerErr) {
          reject(innerErr);
        }
      });
    });
  }

  return Promise.resolve(url);
}
