/**
 * Match raml uri parameters in a uri.
 *
 * @type {RegExp}
 */
const URI_PARAM_REGEXP = /{[^}]+}/g;

/**
 * Simple "template" function for working with the uri param variables.
 *
 * @param  {String}         template
 * @param  {(Object|Array)} context
 * @return {String}
 */
module.exports = function (string, context) {
  context = context || {};

  // No uri string has been specified.
  if (string == null) {
    return null;
  }

  // If the context is an array, we need to transform the replacements into
  // index based positions for the uri template parser.
  if (Array.isArray(context)) {
    let index = 0;

    return string.replace(URI_PARAM_REGEXP, () => {
      const result = encodeURIComponent(context[index] || '');
      index += 1;

      return result;
    });
  }

  return string.replace(URI_PARAM_REGEXP, match => encodeURIComponent(context[match.slice(1, -1)] || ''));
};

/**
 * Export the replacement regexp.
 */
module.exports.REGEXP = URI_PARAM_REGEXP;
