const { expect } = require('chai');
const ramlClient = require('../../../src');

describe('API Platform RAML', () => {
  let client;
  let API;
  let editor;

  before(() => {
    editor = {};

    API = ramlClient({
      redirectUri: 'http://localhost:5000/resources/oauth.html',
      proxy: 'http://localhost:5001/myproxy/',
      authorization: 'my token',
      xhr: XMLHttpRequest,
      sync: true,
      editor: {
        languages: {
          typescript: {
            javascriptDefaults: {
              addExtraLib: (content, file) => {
                editor[file] = content;
              },
              getExtraLibs: () => ({})
            }
          }
        }
      },
      ramlQueryBuilder: ({ groupId, assetId, version }) => `http://localhost:5001/assets/${groupId}/${assetId}/${version}/api/json`
    });
  });

  before(function createClient() {
    this.timeout(10000);

    return API.createClient('client', 'api-platform', 'api.raml', '1.0.0')
      .then((result) => {
        client = result;
      });
  });

  it('creates the client', () => {
    expect(client).to.exist;
    expect(global.client).to.exist;
  });

  context('authorized', () => {
    before(() => API.authenticate(client, null, { clientId: 'client' }));

    it('has the token assigned', () => {
      expect(client['!client'].authentication['OAuth 2.0'].accessToken).to.be.eql('token');
    });

    it('calls a given endpoint', () => (
      client('/organizations/active').get(null, { baseUri: 'http://foo' }, true)
        .then((result) => {
          expect(result.body.id).to.be.eql('my-active-id');
        })
    ));

    it('calls an endpoint with parameters', () => {
      const params = {
        organizationId: 'my-active-id',
        apiName: 'api'
      };

      expect(client('/organizations/{organizationId}/apis/by-name?apiName={apiName}', params).get().body.api).to.be.eql('api');
      expect(client('/organizations/{organizationId}/apis/by-name', params).get({ apiName: 'api' }, null, false).body.api).to.be.eql('api');
    });
  });
});
