const bodyParser = require('body-parser');
const ramlParser = require('raml-1-parser');

const ramlParserConfig = {
  attributeDefaults: true,
  rejectOnErrors: false
};

const expandApi = function (api) {
  api = api.expand ? api.expand(true) : api;

  const jsonOptions = {
    serializeMetadata: false,
    dumpSchemaContents: false,
    rootNodeDetails: false
  };

  return api.toJSON(jsonOptions);
};

module.exports = function (app) {
  app.use(bodyParser.urlencoded({ extended: true }));

  app.get('/assets/:groupId/:assetId/:version/api/json', (req, res) => {
    const { groupId, assetId } = req.params;
    const uri = `http://localhost:5000/resources/${groupId}/${assetId}`;

    return ramlParser.loadApi(uri, ramlParserConfig)
      .then(expandApi)
      .then((api) => {
        res.set('Content-type', 'application/json');
        res.send(JSON.stringify(api));
        res.end();
      });
  });

  app.post('/myproxy/http://localhost:5001/oauth/access_token', (req, res) => {
    res.send('oauth_token=oauth_token&oauth_token_secret=oauth_token_secret');
    res.end();
  });

  app.get('/oauth/authorize', (req, res) => {
    res.writeHead(302, {
      Location: 'http://localhost:5000/resources/oauth.html?oauth_token=oauth_token&oauth_verifier=oauth_verifier'
    });
    res.end();
  });

  app.post('/myproxy/http://localhost:5001/oauth/request_token', (req, res) => {
    res.send('oauth_token=oauth_token&oauth_token_secret=oauth_token_secret');
    res.end();
  });

  app.get('/oauth2/authorize', (req, res) => {
    if (req.query.response_type === 'code') {
      res.writeHead(302, {
        Location: `${req.query.redirect_uri}?state=${req.query.state}&code=foo`
      });
      res.end();
    } else if (req.query.response_type === 'token') {
      res.writeHead(302, {
        Location: `${req.query.redirect_uri}#access_token=token&token_type=bearer&state=${req.query.state}`
      });
      res.end();
    }
  });

  app.post('/myproxy/http://localhost:5001/oauth2/access_token', (req, res) => {
    res.set('Content-type', 'application/json');
    res.send(`{"access_token":"my-token","token_type":"bearer","body":${JSON.stringify(req.body)}}`);
    res.end();
  });

  app.get('/myproxy/http://localhost:5001/content', (req, res) => {
    res.set('Content-type', 'application/json');
    res.send(`{"results":["${req.query.search}"]}`);
    res.end();
  });

  app.get('/myproxy/http://localhost:5001/info', (req, res) => {
    res.set('Content-type', 'application/json');
    res.send('{"info":"my info"}');
    res.end();
  });

  app.get('/myproxy/http://localhost:5001/authorized', (req, res) => {
    res.set('Content-type', 'application/json');
    res.send(`{"header":"${req.headers.authorization}"}`);
    res.end();
  });

  app.get('/myproxy/http://localhost:5001/v1/content', (req, res) => {
    res.set('Content-type', 'application/json');
    res.send(`{"data":["${req.query.search}"]}`);
    res.end();
  });

  app.get('/myproxy/http://localhost:5001/v1/authorized', (req, res) => {
    res.set('Content-type', 'application/json');
    res.send(`{"header":"${req.headers.authorization.replace(/"/g, '\\"')}"}`);
    res.end();
  });

  app.get('/myproxy/http://localhost:5001/v2/content', (req, res) => {
    res.set('Content-type', 'application/json');
    res.send(`{"data":["${req.query.search}"]}`);
    res.end();
  });

  app.get('/myproxy/http://localhost:5001/v2/authorized', (req, res) => {
    res.set('Content-type', 'application/json');
    res.send(`{"header":"${req.headers.authorization.replace(/"/g, '\\"')}"}`);
    res.end();
  });

  app.get('/myproxy/http://localhost:5001/proxy/content', (req, res) => {
    res.set('Content-type', 'application/json');
    res.send(`{"data":["${req.query.search}"],"header":"${req.headers.authorization.replace(/"/g, '\\"')}"}`);
    res.end();
  });

  app.get('/myproxy/http://foo/organizations/active', (req, res) => {
    res.set('Content-type', 'application/json');
    res.send('{"id":"my-active-id"}');
    res.end();
  });

  app.get('/myproxy/https://anypoint.mulesoft.com/apiplatform/repository/organizations/my-active-id/apis/by-name', (req, res) => {
    res.set('Content-type', 'application/json');
    res.send(`{"api":"${req.query.apiName}","param":"${req.query.param}"}`);
    res.end();
  });

  // eslint-disable-next-line no-unused-vars
  app.use((err, req, res, next) => {
    // eslint-disable-next-line no-console
    console.error(err);
    res.status(500);
    res.send('An error occurred');
    res.end();
  });
};
