const { expect } = require('chai');
const ramlClient = require('../../../src');

describe('OAuth1 RAML', () => {
  let client;
  let API;

  before(() => {
    API = ramlClient({
      redirectUri: 'http://localhost:5000/resources/oauth.html',
      proxy: 'http://localhost:5001/myproxy/',
      authorization: 'my token',
      xhr: XMLHttpRequest,
      editor: {
        languages: {
          typescript: {
            javascriptDefaults: {
              addExtraLib: () => {
                // console.log(content);
              },
              getExtraLibs: () => ({})
            }
          }
        }
      },
      ramlQueryBuilder: ({ groupId, assetId, version }) => `http://localhost:5001/assets/${groupId}/${assetId}/${version}/api/json`
    });
  });

  before(() => (
    API.createClient('oauth1', 'oauth1', 'api.raml', '1.0.0', { sync: true })
      .then((result) => {
        client = result;
      })
  ));

  it('creates the client', () => {
    expect(client).to.exist;
    expect(global.oauth1).to.exist;
  });

  it('does an unauthorized api call', () => {
    expect(client.content.get({ search: 'my search' }).body.data).to.eql(['my search']);
  });

  context('authorized', () => {
    before(() => API.authenticate(client, { consumerKey: 'consumerKey', consumerSecret: 'consumerSecret' }));

    it('has the token assigned', () => {
      expect(client['!client'].authentication['OAuth 1.0'].consumerKey).to.be.eql('consumerKey');
      expect(client['!client'].authentication['OAuth 1.0'].consumerSecret).to.be.eql('consumerSecret');
      expect(client['!client'].authentication['OAuth 1.0'].oauthToken).to.be.eql('oauth_token');
      expect(client['!client'].authentication['OAuth 1.0'].oauthTokenSecret).to.be.eql('oauth_token_secret');
    });

    it('does an authorized api call', () => {
      expect(client.authorized.get().body.header).to.exist;
    });
  });
});
