const { expect } = require('chai');
const ramlClient = require('../../../src');

describe('OAuth2 code JSON RAML', () => {
  let client;
  let API;

  before(() => {
    API = ramlClient({
      redirectUri: 'http://localhost:5000/resources/oauth.html',
      proxy: 'http://localhost:5001/myproxy/',
      authorization: 'my token',
      sync: true,
      xhr: XMLHttpRequest
    });
  });

  before(() => (
    API.createClient('oauth2JSON', 'http://localhost:5000/resources/json/api.json')
      .then((result) => {
        client = result;
      })
  ));

  it('creates the client', () => {
    expect(client).to.exist;
    expect(global.oauth2JSON).to.exist;
  });

  context('authorized', () => {
    before(() => API.authenticate(client, { clientId: 'client', clientSecret: 'secret', scopes: ['user'] }));

    it('has the token assigned', () => {
      expect(client['!client'].authentication['OAuth 2.0'].clientId).to.be.eql('client');
      expect(client['!client'].authentication['OAuth 2.0'].accessToken).to.be.eql('my-token');
    });

    it('does an authorized api call', () => {
      expect(client.info.get().body.info).to.eql('my info');
    });
  });
});
