const { expect } = require('chai');
const ramlClient = require('../../../src');

describe('OAuth2 token RAML', () => {
  let client;
  let API;

  before(() => {
    API = ramlClient({
      redirectUri: 'http://localhost:5000/resources/oauth.html',
      proxy: 'http://localhost:5001/myproxy/',
      prompt: () => Promise.resolve({
        clientId: 'client',
        scopes: ['user']
      }),
      authorization: 'my token',
      sync: true,
      xhr: XMLHttpRequest,
      ramlQueryBuilder: ({ groupId, assetId, version }) => `http://localhost:5001/assets/${groupId}/${assetId}/${version}/api/json`
    });
  });

  before(() => (
    API.createClient('oauth2Token', 'oauth2-token', 'api.raml', '1.0.0')
      .then((result) => {
        client = result;
      })
  ));

  it('creates the client', () => {
    expect(client).to.exist;
    expect(global.oauth2Token).to.exist;
  });

  it('does an api call', () => {
    expect(client.content.get({ search: 'my search' }).body.results).to.eql(['my search']);
  });

  context('authorized', () => {
    before(() => API.authenticate(client));

    it('has the token assigned', () => {
      expect(client['!client'].authentication['OAuth 2.0'].accessToken).to.be.eql('token');
    });

    it('does an authorized api call', () => {
      expect(client.authorized.get().body.header).to.eql('Bearer token');
    });
  });
});
