const { expect } = require('chai');
const path = require('path');
const ramlClient = require('../../../src');

describe('OAuth2 client credentials RAML', () => {
  let client;
  let API;

  before(() => {
    API = ramlClient();
  });

  before(() => (
    API.createClient(path.join(process.cwd(), 'test/resources/oauth2-credentials/api.raml'))
      .then((result) => {
        client = result;
      })
  ));

  it('creates the client', () => {
    expect(client).to.exist;
  });

  it('does an api call', (done) => {
    client.content.get({ search: 'my search' })
      .then((response) => {
        expect(response.body.results).to.eql(['my search']);
        done();
      });
  });

  context('authorized', () => {
    before(() => API.authenticate(client, { clientId: 'client', clientSecret: 'secret', scopes: ['user'] })
      .then(($client) => {
        expect(client).to.be.eql($client);
      }));

    it('has the token assigned', () => {
      expect(client['!client'].authentication['OAuth 2.0'].accessToken).to.be.eql('my-token');
    });

    it('does an authorized api call', (done) => {
      client.authorized.get()
        .then((response) => {
          expect(response.body.header).to.eql('Bearer my-token');
          done();
        });
    });
  });
});
